@@ -519,13 +519,14 @@ if (nrow(dgelist$counts) == 0) {
     } else {
         results_to_output <- result[significant, ]
     }
-    blank <- mapply(function(i){ all(is.na(results_to_output[,i])) }, 1:ncol(result))
 
     if (OUTPUT_COUNTS) {
         # Add raw counts
         results_to_output <- cbind(results_to_output, dgelist$counts[rownames(results_to_output),])
     }
 
+    blank <- mapply(function(i){ all(is.na(results_to_output[,i])) }, 1:ncol(results_to_output))
+
     #write.table(results_to_output[,!blank], OUTPUT_FILENAME, sep='\t', na='', quote=FALSE, row.names=FALSE)
 
     sink(OUTPUT_FILENAME)
@@ -759,7 +760,7 @@ if ((MODE == 'glog' || MODE == 'voom') && ncol(coef) == 1) {
 
 result$p <- p
 
-result$FDR <- p.adjust(p)
+result$FDR <- p.adjust(p, method='BH')
 
 #for(i in (N_ALL_SAMPLES*2+2):ncol(data)) {
 #    result[,colnames(data)[i]] = data[,i]
@@ -786,13 +787,14 @@ if (OUTPUT_ALL) {
 } else {
     results_to_output <- result[significant,]
 }
-blank <- mapply(function(i){ all(is.na(results_to_output[,i])) }, 1:ncol(result))
 
 if (OUTPUT_COUNTS) {
     # Add raw counts
     results_to_output <- cbind(results_to_output, dgelist$counts[rownames(results_to_output),])
 }
 
+blank <- mapply(function(i){ all(is.na(results_to_output[,i])) }, 1:ncol(results_to_output))
+
 #write.table(results_to_output[,!blank,drop=FALSE], OUTPUT_FILENAME, sep='\t', na='', quote=FALSE, row.names=FALSE)
 sink(OUTPUT_FILENAME)
 write.csv(results_to_output[,!blank,drop=FALSE], na='', row.names=FALSE)
@@ -883,7 +885,7 @@ library(goseq)
 
 report <- function(result,col, significant,direction,categories) {
     good <- result
-    good$fdr <- p.adjust(good[,col])    
+    good$fdr <- p.adjust(good[,col], method='BH')    
     good <- good[order(good[,col]),]
     
     good <- good[good$fdr < 0.5,,drop=FALSE]
@@ -929,12 +931,21 @@ report <- function(result,col, significant,direction,categories) {
 }
 
 analyse <- function(significant,direction,length,categories) {
-    pwf <- nullp(significant, bias.data=length, plot.fit=FALSE)
-    result <- goseq(pwf,gene2cat=categories)
-    cat('\nOver-represented categories:\n\n')
-    report(result,'over_represented_pvalue', significant,direction,categories)
-    cat('\nUnder-represented categories:\n\n')
-    report(result,'under_represented_pvalue', significant,direction,categories)    
+    pwf <- tryCatch({
+            nullp(significant, bias.data=length, plot.fit=FALSE)
+        }, error=function(err) { 
+            NULL 
+        })
+    
+    if (is.null(pwf)) {
+        cat('\n\ngoseq function "nullp" failed.\n\n')
+    } else {
+        result <- goseq(pwf,gene2cat=categories)
+        cat('\nOver-represented categories:\n\n')
+        report(result,'over_represented_pvalue', significant,direction,categories)
+        cat('\nUnder-represented categories:\n\n')
+        report(result,'under_represented_pvalue', significant,direction,categories)    
+    }
 }
 
 
